==> weboob_1.2.orig.tar.gz: weboob-1.2/modules/leboncoin/module.py <==
# -*- coding: utf-8 -*-

# Copyright(C) 2014      Bezleputh
#
# This file is part of weboob.
#
# weboob is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# weboob is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with weboob. If not, see <http://www.gnu.org/licenses/>.


from weboob.tools.backend import Module, BackendConfig
from weboob.capabilities.housing import CapHousing, Housing, HousingPhoto
from weboob.tools.value import Value
from .browser import LeboncoinBrowser


__all__ = ['LeboncoinModule']


class LeboncoinModule(Module, CapHousing):
    NAME = 'leboncoin'
    DESCRIPTION = u'search house on leboncoin website'
    MAINTAINER = u'Bezleputh'
    EMAIL = 'carton_ben@yahoo.fr'
    LICENSE = 'AGPLv3+'
    VERSION = '1.2'

    BROWSER = LeboncoinBrowser

    CONFIG = BackendConfig(Value('advert_type', label='Advert type',
                                 choices={'c': 'Agency', 'p': 'Owner', 'a': 'All'}, default='a'),
                           Value('region', label='Region',
                                 choices=['alsace',
                                          'aquitaine',
                                          'auvergne',
                                          'basse_normandie',
                                          'bourgogne',
                                          'bretagne',
                                          'centre',
                                          'champagne_ardenne',
                                          'corse',
                                          'franche_comte',
                                          'haute_normandie',
                                          'ile_de_france',
                                          'languedoc_roussillon',
                                          'limousin',
                                          'lorraine',
                                          'midi_pyrenees',
                                          'nord_pas_de_calais',
                                          'pays_de_la_loire',
                                          'picardie',
                                          'poitou_charentes',
                                          'provence_alpes_cote_d_azur',
                                          'rhone_alpes',
                                          'guadeloupe',
                                          'martinique',
                                          'guyane',
                                          'reunion']))

    def create_default_browser(self):
        region = self.config['region'].get()
        return self.create_browser(region)

    def get_housing(self, _id):
        return self.browser.get_housing(_id)

    def fill_housing(self, housing, fields):
        return self.browser.get_housing(housing.id, housing)

    def fill_photo(self, photo, fields):
        if 'data' in fields and photo.url and not photo.data:
            photo.data = self.browser.open(photo.url).content
        return photo

    def search_city(self, pattern):
        return self.browser.get_cities(pattern)

    def search_housings(self, query):
        return self.browser.search_housings(query, self.config['advert_type'].get(), self.name)

    OBJECTS = {Housing: fill_housing, HousingPhoto: fill_photo}

==> weboob_1.3.orig.tar.gz: weboob-1.3/modules/leboncoin/module.py <==
# -*- coding: utf-8 -*-

# Copyright(C) 2014      Bezleputh
#
# This file is part of weboob.
#
# weboob is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# weboob is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with weboob. If not, see <http://www.gnu.org/licenses/>.


from weboob.tools.backend import Module, BackendConfig
from weboob.capabilities.housing import CapHousing, Housing, HousingPhoto
from weboob.tools.value import Value
from .browser import LeboncoinBrowser


__all__ = ['LeboncoinModule']


class LeboncoinModule(Module, CapHousing):
    NAME = 'leboncoin'
    DESCRIPTION = u'search house on leboncoin website'
    MAINTAINER = u'Bezleputh'
    EMAIL = 'carton_ben@yahoo.fr'
    LICENSE = 'AGPLv3+'
    VERSION = '1.3'

    BROWSER = LeboncoinBrowser

    CONFIG = BackendConfig(
        Value('advert_type', label='Advert type',
              choices={'c': 'Agency', 'p': 'Owner', 'a': 'All'}, default='a')
    )

    def create_default_browser(self):
        return self.create_browser()

    def get_housing(self, _id):
        return self.browser.get_housing(_id)

    def fill_housing(self, housing, fields):
        return self.browser.get_housing(housing.id, housing)

    def fill_photo(self, photo, fields):
        if 'data' in fields and photo.url and not photo.data:
            photo.data = self.browser.open(photo.url).content
        return photo

    def search_city(self, pattern):
        return self.browser.get_cities(pattern)

    def search_housings(self, query):
        return self.browser.search_housings(query, self.config['advert_type'].get(), self.name)

    OBJECTS = {Housing: fill_housing, HousingPhoto: fill_photo}
